@@ -356,6 +356,13 @@ impl<R: Sized> Polynomial<R> {
         }
         Polynomial::new(coef)
     }
+    fn scalar_mul_assign_impl(&mut self, alpha: &R)
+    where
+        R: Sized + Zero + for<'x> MulAssign<&'x R>,
+    {
+        self.coef.iter_mut().for_each(|c| *c *= alpha);
+        self.trim_zero();
+    }
 }
 
 // field
@@ -458,4 +465,10 @@ impl<K: Sized> Polynomial<K> {
         let f = ring_algorithm::gcd::<Self>(self.clone(), d).into_normalize();
         (self / &f).into_normalize()
     }
+    fn scalar_div_assign_impl(&mut self, alpha: &K)
+    where
+        K: Sized + Zero + for<'x> DivAssign<&'x K>,
+    {
+        self.coef.iter_mut().for_each(|c| *c /= alpha);
+    }
 }
